#
# spec file for package erfa
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define lname	liberfa1
Name:           erfa
Version:        2.0.1
Release:        1.7
Summary:        Essential Routines for Fundamental Astronomy
License:        BSD-3-Clause
Group:          Productivity/Scientific/Other
URL:            https://github.com/liberfa/erfa
Source:         https://github.com/liberfa/erfa/releases/download/v%{version}/erfa-%{version}.tar.xz
BuildRequires:  meson
BuildRequires:  pkgconfig

%description
ERFA is a C library containing key algorithms for astronomy, and is based on
the SOFA library published by the International Astronomical Union (IAU).

%package -n %{lname}
Summary:        Essential Routines for Fundamental Astronomy
Group:          System/Libraries

%description -n %{lname}
ERFA is a C library containing key algorithms for astronomy, and is based on
the SOFA library published by the International Astronomical Union (IAU).

ERFA is intended to replicate the functionality of SOFA (aside from possible
bugfixes in ERFA that have not yet been included in SOFA), but is licensed
under a three-clause BSD license to enable its compatibility with a wide
range of open source licenses. Permission for this release has been obtained
from the SOFA board, and is avilable in the LICENSE file included in this
source distribution.

%package        devel
Summary:        Development files for %{name}
Group:          Development/Libraries/C and C++
Requires:       %{lname} = %{version}

%description    devel
This package contains libraries and header files for developing
applications that use %{name}.

%prep
%setup -q

%build
%meson
%meson_build

%install
%meson_install

%post   -n %{lname} -p /sbin/ldconfig
%postun -n %{lname} -p /sbin/ldconfig

%files -n %{lname}
%license LICENSE
%doc INFO README.rst
%{_libdir}/liberfa.so.1
%{_libdir}/liberfa.so.1.*

%files devel
%{_includedir}/*.h
%{_libdir}/liberfa.so
%{_libdir}/pkgconfig/erfa.pc

%changelog
* Wed Oct 18 2023 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 2.0.1:
  * Based on SOFA "20231011".
  * Added capability to modify at runtime the leap seconds assumed
    for various calculations, accessed via the eraGetLeapSeconds
    and eraSetLeapSeconds functions
- Switch to meson for builds as recommended by upstream; add
  BuildRequires: meson.
- Drop erfa-devel-static package: no longer built by default.
- No longer pass -ffat-lto-objects as static lib is not built.
* Tue May 18 2021 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 2.0.0:
  * Based on SOFA 20210512; there are no differences except for
    added eraVersion, eraSofaVersion, and leap second functions.
  * Three new functions added in SOFA are added to ERFA as well.
  * Required to explicitly include erfam.h to use its macros
    defining constants, etc. Including just erfa.h (or
    erfaextra.h) will no longer includes erfam.h implicitly.
* Sat May  8 2021 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 1.7.3:
  * Based on SOFA 20210125_a.
* Thu Feb 25 2021 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 1.7.2:
  * Incorporating big fixes from SOFA version 20210125.
* Sat Sep 19 2020 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 1.7.1:
  * Based on SOFA version 20200721.
* Tue Dec 31 2019 Sebastian Wagner <sebix+novell.com@sebix.at>
- Update to version 1.7.0:
  * Based on "20190722" except for the added `eraVersion`,
    `eraSofaVersion`, and leap second functions.
* Wed Oct 30 2019 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 1.6.0:
  * Based on SOFA version 20190722.
- Running bootstrap.sh before configure is no longer needed; also
  drop automake, autoconf, and libtool BuildRequires.
* Wed Sep 11 2019 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 1.5.0:
  * Based on SOFA 20180130
* Tue Sep 10 2019 Christophe Giboudeaux <christophe@krop.fr>
- Use -ffat-lto-objects when building static libraries.
- Run spec-cleaner
* Wed Sep 13 2017 badshah400@gmail.com
- Update to version 1.4.0:
  - ERFA 1.4.0 adds the eraVersion and eraSofaVersion functions to
    determine the installed version of ERFA (and the SOFA version
    it is derived from).
  - ERFA 1.4.0 includes some bug fixes contributed to ERFA after
    1.3.0 but before 1.4.0. These were incorporated (with
    modification) into SOFA "20170420" (without attribution) and
    hence these are not differences between ERFA and SOFA
    (gh#liberfa/erfa#40, gh#liberfa/erfa#41).
* Wed May 24 2017 toddrme2178@gmail.com
- Update to version 1.3.0
  * based on SOFA version "20160503_a"
* Sun Jul 17 2016 jengelh@inai.de
- erfa-devel needs to require liberfa1, not erfa1.
* Thu Jul 14 2016 matwey.kornilov@gmail.com
- Do not package *.la as required by guidelines
* Thu Jan 28 2016 toddrme2178@gmail.com
- Update to version 1.2.0
  * based on SOFA version "20150209_a"
* Thu May 21 2015 toddrme2178@gmail.com
- Update to version 1.1.1
  * No upstream changelog
* Sun Mar  8 2015 arun@gmx.de
- specfile:
  * update copyright year
  * remove RELEASE.rst,  not in tar-ball anymore
- update to version 1.1.1:
  * Update to SOFA 2015-02-09
  * updated ERFA_LIB_VERSION_INFO to reflect new version
  * Update package version info
  * pdate to latest ERFA source
  * Renamed tk to tc in erfa.h
- changes from version 1.1.0:
  * Added bugfix section and discussion of #14
  * Minor typo fix
  * Update to 20131202_b
  * Import SOFA 20131202
* Thu Feb  6 2014 toddrme2178@gmail.com
- Fix devel package requires
* Tue Feb  4 2014 toddrme2178@gmail.com
- Initial version (1.0.1)
